# Table of Contents

- [roadmap-report](<./roadmap-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Roadmap Report](<./Roadmap-Report.md>)
  - [HOW is it useful?](<./Roadmap-Report/HOW-is-it-useful.md>)
  - [Using the Roadmap Reports](<./Roadmap-Report/Using-the-Roadmap-Reports.md>)
  - [Applying Filter](<./Roadmap-Report/Applying-Filter.md>)
  - [Editing in the Report](<./Roadmap-Report/Editing-in-the-Report.md>)
  - [Clustering in Roadmap Report](<./Roadmap-Report/Clustering-in-Roadmap-Report.md>)
  - [Clear Overview of Successor](<./Roadmap-Report/Clear-Overview-of-Successor.md>)
  - [Hide Applications Outside the Defined Timeline](<./Roadmap-Report/Hide-Applications-Outside-the-Defined-Timeline.md>)
  - [Was this page helpful?](<./Roadmap-Report/Was-this-page-helpful.md>)
